@@ -8,7 +8,7 @@ from bs4 import BeautifulSoup
 from pandas.io.formats.style import Styler
 import matplotlib.pyplot as plt
 
-INPUT_FILES_FOLDER = Path(os.path.join('tests', 'input_data'))
+INPUT_FILES_FOLDER = Path(__file__).parent / "input_data"
 DF_STYLED_PATH = os.path.join(INPUT_FILES_FOLDER, 'df_styled.html')
 DF_LABELED_PATH = os.path.join(INPUT_FILES_FOLDER, 'df_labeled.html')
 DF_STYLED_NUM_FMT_PATH = os.path.join(INPUT_FILES_FOLDER, 'df_styled_num_fmt.html')
@@ -78,7 +78,7 @@ def assert_styled_matches(styler: Styler, file_path: str = DF_STYLED_PATH, gener
 
 
 def _prettify_html(html: str) -> str:
-    soup = BeautifulSoup(html)
+    soup = BeautifulSoup(html, "html.parser")
     return soup.prettify()
 
 
